Skip to contents

Returns a data.frame describing the available climatic data versions and their temporal coverage (initial and latest available years).

Usage

get_periods()

Value

A data.frame containing the available climate data versions and their corresponding initial and latest available years.

References

For details on the latest version of the climatic data, see: Pucher, Christoph (2026). Description of Downscaled European Climate Data. figshare. Online resource. https://doi.org/10.6084/m9.figshare.33078053.v1

For details on version 4, see: Pucher C. 2023. Description and Evaluation of Downscaled Daily Climate Data Version 4. https://doi.org/10.6084/m9.figshare.22962671.v1

Adam Moreno, Hubert Hasenauer. 2016. Spatial downscaling of European climate data. International Journal of Climatology 36: 1444–1458.

Author

Sofia Miguel